==> haskell-concise-0.1.0.1-603-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-EFHHNfGDrPyBh29SjSKRLI
key:                  concise-0.1.0.1-EFHHNfGDrPyBh29SjSKRLI
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  ae1c4f98bea316e93d6ba2a771a791e9
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-EFHHNfGDrPyBh29SjSKRLI
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3-FNJYFG5nVy3K1UtPWTWg2x
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-604-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-3lprtXXkeTw59MzV5NEXGT
key:                  concise-0.1.0.1-3lprtXXkeTw59MzV5NEXGT
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  ef1754bf6b45499747c95b692402d40d
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-3lprtXXkeTw59MzV5NEXGT
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3.1-3FYsDpCHEKEBLMSbQ9nAqF
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
